@@ -118,8 +118,8 @@ def get_prediction(
 def get_sliced_prediction(
     image,
     detection_model=None,
-    slice_height: int = 512,
-    slice_width: int = 512,
+    slice_height: int = None,
+    slice_width: int = None,
     overlap_height_ratio: float = 0.2,
     overlap_width_ratio: float = 0.2,
     perform_standard_pred: bool = True,
@@ -129,6 +129,7 @@ def get_sliced_prediction(
     postprocess_class_agnostic: bool = False,
     verbose: int = 1,
     merge_buffer_length: int = None,
+    auto_slice_resolution: bool = True,
 ) -> PredictionResult:
     """
     Function for slice image + get predicion for each slice + combine predictions in full image.
@@ -138,9 +139,9 @@ def get_sliced_prediction(
             Location of image or numpy image matrix to slice
         detection_model: model.DetectionModel
         slice_height: int
-            Height of each slice.  Defaults to ``512``.
+            Height of each slice.  Defaults to ``None``.
         slice_width: int
-            Width of each slice.  Defaults to ``512``.
+            Width of each slice.  Defaults to ``None``.
         overlap_height_ratio: float
             Fractional overlap in height of each window (e.g. an overlap of 0.2 for a window
             of size 512 yields an overlap of 102 pixels).
@@ -171,6 +172,9 @@ def get_sliced_prediction(
             The length of buffer for slices to be used during sliced prediction, which is suitable for low memory.
             It may affect the AP if it is specified. The higher the amount, the closer results to the non-buffered.
             scenario. See [the discussion](https://github.com/obss/sahi/pull/445).
+        auto_slice_resolution: bool
+            if slice parameters (slice_height, slice_width) are not given,
+            it enables automatically calculate these params from image resolution and orientation.
 
     Returns:
         A Dict with fields:
@@ -192,6 +196,7 @@ def get_sliced_prediction(
         slice_width=slice_width,
         overlap_height_ratio=overlap_height_ratio,
         overlap_width_ratio=overlap_width_ratio,
+        auto_slice_resolution=auto_slice_resolution,
     )
     num_slices = len(slice_image_result)
     time_end = time.time() - time_start
@@ -255,6 +260,13 @@ def get_sliced_prediction(
         )
         object_prediction_list.extend(prediction_result.object_prediction_list)
 
+    # merge matching predictions
+    if len(object_prediction_list) > 1:
+        object_prediction_list = postprocess(object_prediction_list)
+
+    time_end = time.time() - time_start
+    durations_in_seconds["prediction"] = time_end
+
     if verbose == 2:
         print(
             "Slicing performed in",
@@ -267,13 +279,6 @@ def get_sliced_prediction(
             "seconds.",
         )
 
-    # merge matching predictions
-    if len(object_prediction_list) > 1:
-        object_prediction_list = postprocess(object_prediction_list)
-
-    time_end = time.time() - time_start
-    durations_in_seconds["prediction"] = time_end
-
     return PredictionResult(
         image=image, object_prediction_list=object_prediction_list, durations_in_seconds=durations_in_seconds
     )
@@ -520,7 +525,10 @@ def predict(
 
         durations_in_seconds["prediction"] += prediction_result.durations_in_seconds["prediction"]
         # Show prediction time
-        tqdm.write("Prediction time is: {:.2f} ms".format(prediction_result.durations_in_seconds["prediction"] * 1000))
+        if verbose:
+            tqdm.write(
+                "Prediction time is: {:.2f} ms".format(prediction_result.durations_in_seconds["prediction"] * 1000)
+            )
 
         if dataset_json_path:
             if source_is_video is True:
